# Class: Repository

Repository for updates

## Fields for class: Repository

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`binary_url`        |`string`            |_RO/constructor_|Base URL of binary packages in this repository|
|`gpgkey_path`       |`string`            |_RO/constructor_|The file name of the GPG public key of this repository|
|`hash`              |`string`            |_RO/runtime_   |SHA256 checksum of latest updateinfo.xml.gz in this repository if its 'update' is true|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`origin`            |`origin`            |_RO/constructor_|The origin of the repository. 'remote' if the origin of the repository is a remote one, 'bundle' if the origin of the repository is a local bundle file.|
|`source_url`        |`string`            |_RO/constructor_|Base URL of source packages in this repository|
|`up_to_date`        |`bool`              |_RO/runtime_   |**Removed.** True if all hosts in pool is up to date with this repository|
|`update`            |`bool`              |_RO/constructor_|True if updateinfo.xml in this repository needs to be parsed|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: Repository

### RPC name: forget

_Overview:_

Remove the repository record from the database

_Signature:_

```
void forget (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |The repository to be removed from the database|

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the Repositorys known to the system.

_Signature:_

```
Repository ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Repository ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Repository references to Repository records for all Repositorys known to the system.

_Signature:_

```
(Repository ref -> Repository record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Repository ref -> Repository record) map`

records of all objects

### RPC name: get&#95;binary&#95;url

_Overview:_

Get the binary&#95;url field of the given Repository.

_Signature:_

```
string get_binary_url (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the Repository instances with the given label.

_Signature:_

```
Repository ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `Repository ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Repository instance with the specified UUID.

_Signature:_

```
Repository ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Repository ref`

reference to the object

### RPC name: get&#95;gpgkey&#95;path

_Overview:_

Get the gpgkey&#95;path field of the given Repository.

_Signature:_

```
string get_gpgkey_path (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;hash

_Overview:_

Get the hash field of the given Repository.

_Signature:_

```
string get_hash (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given Repository.

_Signature:_

```
string get_name_description (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given Repository.

_Signature:_

```
string get_name_label (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;origin

_Overview:_

Get the origin field of the given Repository.

_Signature:_

```
origin get_origin (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `origin`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Repository.

_Signature:_

```
Repository record get_record (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Repository record`

all fields from the object

### RPC name: get&#95;source&#95;url

_Overview:_

Get the source&#95;url field of the given Repository.

_Signature:_

```
string get_source_url (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;up&#95;to&#95;date

**This message is removed.**

_Overview:_

Get the up&#95;to&#95;date field of the given Repository.

_Signature:_

```
bool get_up_to_date (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;update

_Overview:_

Get the update field of the given Repository.

_Signature:_

```
bool get_update (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Repository.

_Signature:_

```
string get_uuid (session ref session_ref, Repository ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: introduce

_Overview:_

Add the configuration for a new remote repository

_Signature:_

```
Repository ref introduce (session ref session_ref, string name_label, string name_description, string binary_url, string source_url, bool update, string gpgkey_path)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name_label`                  |The name of the repository              |
|`string`                      |`name_description`            |The description of the repository       |
|`string`                      |`binary_url`                  |Base URL of binary packages in this repository|
|`string`                      |`source_url`                  |Base URL of source packages in this repository|
|`bool`                        |`update`                      |True if the repository is an update repository. This means that updateinfo.xml will be parsed|
|`string`                      |`gpgkey_path`                 |The GPG public key file name            |

_Minimum Role:_ client-cert

_Return Type:_ `Repository ref`

The ref of the created repository record.

### RPC name: introduce&#95;bundle

_Overview:_

Add the configuration for a new bundle repository

_Signature:_

```
Repository ref introduce_bundle (session ref session_ref, string name_label, string name_description)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name_label`                  |The name of the repository              |
|`string`                      |`name_description`            |The description of the repository       |

_Minimum Role:_ client-cert

_Return Type:_ `Repository ref`

The ref of the created repository record.

### RPC name: set&#95;gpgkey&#95;path

_Overview:_

Set the file name of the GPG public key of the repository

_Signature:_

```
void set_gpgkey_path (session ref session_ref, Repository ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |The repository                          |
|`string`                      |`value`                       |The file name of the GPG public key of the repository|

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given Repository.

_Signature:_

```
void set_name_description (session ref session_ref, Repository ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given Repository.

_Signature:_

```
void set_name_label (session ref session_ref, Repository ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Repository ref`              |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ client-cert

_Return Type:_ `void`
