# Class: VM&#95;group

A VM group

## Fields for class: VM&#95;group

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`placement`         |`placement_policy`  |_RO/constructor_|The placement policy of the VM group    |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VMs`               |`VM ref set`        |_RO/runtime_   |The list of VMs associated with the group|

## RPCs associated with class: VM&#95;group

### RPC name: create

_Overview:_

Create a new VM&#95;group instance, and return its handle.

_Signature:_

```
VM_group ref create (session ref session_ref, VM_group record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group record`             |`args`                        |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VM_group ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified VM&#95;group instance.

_Signature:_

```
void destroy (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;groups known to the system.

_Signature:_

```
VM_group ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VM_group ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;group references to VM&#95;group records for all VM&#95;groups known to the system.

_Signature:_

```
(VM_group ref -> VM_group record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VM_group ref -> VM_group record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VM&#95;group instances with the given label.

_Signature:_

```
VM_group ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VM_group ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;group instance with the specified UUID.

_Signature:_

```
VM_group ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_group ref`

reference to the object

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VM&#95;group.

_Signature:_

```
string get_name_description (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VM&#95;group.

_Signature:_

```
string get_name_label (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;placement

_Overview:_

Get the placement field of the given VM&#95;group.

_Signature:_

```
placement_policy get_placement (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `placement_policy`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;group.

_Signature:_

```
VM_group record get_record (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_group record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;group.

_Signature:_

```
string get_uuid (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VMs

_Overview:_

Get the VMs field of the given VM&#95;group.

_Signature:_

```
VM ref set get_VMs (session ref session_ref, VM_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given VM&#95;group.

_Signature:_

```
void set_name_description (session ref session_ref, VM_group ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given VM&#95;group.

_Signature:_

```
void set_name_label (session ref session_ref, VM_group ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_group ref`                |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`
